@@ -28,7 +28,7 @@ def distance_portion(nodes1, nodes2, mode):
     if mode == 'ms':
         return torch.sum((nodes1 - nodes2) ** 2, dim=-1)
     elif mode == 'L2':
-        return torch.sum((nodes1 - nodes2) ** 2, dim=-1).sqrt()
+        return (torch.sum((nodes1 - nodes2) ** 2, dim=-1) + 1e-5).sqrt()
     elif mode == 'L1':
         return torch.sum(abs(nodes1 - nodes2), dim=-1)
     elif mode == 'cosine':
